@@ -1,3 +1,20 @@
+/*
+SPDX-License-Identifier: Apache-2.0
+
+Copyright Contributors to the Submariner project.
+
+Licensed under the Apache License, Version 2.0 (the "License");
+you may not use this file except in compliance with the License.
+You may obtain a copy of the License at
+
+    http://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS,
+WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+See the License for the specific language governing permissions and
+limitations under the License.
+*/
 package discovery
 
 import (
@@ -14,8 +31,8 @@ import (
 )
 
 const (
-	submarinerIpamGlobalIp = "submariner.io/globalIp"
-	clustersetDomain       = "clusterset.local"
+	clustersetDomain = "clusterset.local"
+	not              = " not"
 )
 
 // Both domains need to be checked, until the operator is updated to use clusterset
@@ -42,7 +59,6 @@ var _ = Describe("[discovery] Test Service Discovery Across Clusters", func() {
 			RunServiceExportTest(f)
 		})
 	})
-
 	When("there are no active pods for a service", func() {
 		It("should not resolve the service", func() {
 			RunServicesPodAvailabilityTest(f)
@@ -102,7 +118,6 @@ func RunServiceDiscoveryTest(f *lhframework.Framework) {
 
 	nginxServiceClusterB := f.NewNginxService(framework.ClusterB)
 
-	f.AwaitGlobalnetIP(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace)
 	f.NewServiceExport(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace)
 
 	f.AwaitServiceExportedStatusCondition(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace)
@@ -115,20 +130,29 @@ func RunServiceDiscoveryTest(f *lhframework.Framework) {
 	Expect(err).NotTo(HaveOccurred())
 
 	nginxServiceClusterB = svc
-	f.AwaitServiceImportIP(framework.ClusterA, nginxServiceClusterB)
+	f.AwaitServiceImportIP(framework.ClusterB, framework.ClusterA, nginxServiceClusterB)
 	f.AwaitEndpointSlices(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace, 1, 1)
 	f.AwaitEndpointSlices(framework.ClusterA, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace, 1, 1)
 
-	verifyServiceIpWithDig(f.Framework, framework.ClusterA, framework.ClusterB, nginxServiceClusterB, netshootPodList, checkedDomains,
+	f.VerifyServiceIPWithDig(framework.ClusterA, framework.ClusterB, nginxServiceClusterB, netshootPodList, checkedDomains,
 		"", true)
 
+	verifySRVWithDig(f.Framework, framework.ClusterA, nginxServiceClusterB, netshootPodList, checkedDomains, "",
+		true, true)
+	verifySRVWithDig(f.Framework, framework.ClusterA, nginxServiceClusterB, netshootPodList, checkedDomains, "",
+		false, true)
+
 	f.DeleteServiceExport(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace)
 	f.AwaitServiceImportDelete(framework.ClusterA, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace)
 
 	f.DeleteService(framework.ClusterB, nginxServiceClusterB.Name)
 
-	verifyServiceIpWithDig(f.Framework, framework.ClusterA, framework.ClusterB, nginxServiceClusterB, netshootPodList, checkedDomains,
-		"", false)
+	f.VerifyIPWithDig(framework.ClusterA, nginxServiceClusterB, netshootPodList, checkedDomains,
+		"", "", true)
+	verifySRVWithDig(f.Framework, framework.ClusterA, nginxServiceClusterB, netshootPodList, checkedDomains, "",
+		true, false)
+	verifySRVWithDig(f.Framework, framework.ClusterA, nginxServiceClusterB, netshootPodList, checkedDomains, "",
+		false, false)
 }
 
 func RunServiceDiscoveryLocalTest(f *lhframework.Framework) {
@@ -149,7 +173,6 @@ func RunServiceDiscoveryLocalTest(f *lhframework.Framework) {
 
 	nginxServiceClusterB := f.NewNginxService(framework.ClusterB)
 
-	f.AwaitGlobalnetIP(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace)
 	f.NewServiceExport(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace)
 
 	f.AwaitServiceExportedStatusCondition(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace)
@@ -159,7 +182,7 @@ func RunServiceDiscoveryLocalTest(f *lhframework.Framework) {
 	netshootPodList := f.NewNetShootDeployment(framework.ClusterA)
 	clusterADomain := getClusterDomain(f.Framework, framework.ClusterA, netshootPodList)
 
-	verifyServiceIpWithDig(f.Framework, framework.ClusterA, framework.ClusterA, nginxServiceClusterA, netshootPodList,
+	f.VerifyServiceIPWithDig(framework.ClusterA, framework.ClusterA, nginxServiceClusterA, netshootPodList,
 		[]string{clusterADomain}, "", true)
 
 	f.DeleteService(framework.ClusterA, nginxServiceClusterA.Name)
@@ -168,11 +191,11 @@ func RunServiceDiscoveryLocalTest(f *lhframework.Framework) {
 	Expect(err).NotTo(HaveOccurred())
 
 	nginxServiceClusterB = svc
-	f.AwaitServiceImportIP(framework.ClusterA, nginxServiceClusterB)
+	f.AwaitServiceImportIP(framework.ClusterB, framework.ClusterA, nginxServiceClusterB)
 	f.AwaitEndpointSlices(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace, 1, 1)
 	f.AwaitEndpointSlices(framework.ClusterA, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace, 1, 1)
 
-	verifyServiceIpWithDig(f.Framework, framework.ClusterA, framework.ClusterB, nginxServiceClusterB, netshootPodList, checkedDomains,
+	f.VerifyServiceIPWithDig(framework.ClusterA, framework.ClusterB, nginxServiceClusterB, netshootPodList, checkedDomains,
 		"", true)
 
 	f.DeleteServiceExport(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace)
@@ -180,8 +203,7 @@ func RunServiceDiscoveryLocalTest(f *lhframework.Framework) {
 
 	f.DeleteService(framework.ClusterB, nginxServiceClusterB.Name)
 
-	verifyServiceIpWithDig(f.Framework, framework.ClusterA, framework.ClusterB, nginxServiceClusterB, netshootPodList, checkedDomains,
-		"", false)
+	f.VerifyIPWithDig(framework.ClusterA, nginxServiceClusterB, netshootPodList, checkedDomains, "", "", true)
 }
 
 func RunServiceExportTest(f *lhframework.Framework) {
@@ -197,8 +219,6 @@ func RunServiceExportTest(f *lhframework.Framework) {
 
 	nginxServiceClusterB := f.NewNginxService(framework.ClusterB)
 
-	f.AwaitGlobalnetIP(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace)
-
 	By(fmt.Sprintf("Creating a Netshoot Deployment on %q", clusterAName))
 
 	netshootPodList := f.NewNetShootDeployment(framework.ClusterA)
@@ -207,18 +227,17 @@ func RunServiceExportTest(f *lhframework.Framework) {
 	Expect(err).NotTo(HaveOccurred())
 
 	nginxServiceClusterB = svc
-	f.AwaitServiceImportIP(framework.ClusterA, nginxServiceClusterB)
+	f.AwaitServiceImportIP(framework.ClusterB, framework.ClusterA, nginxServiceClusterB)
 	f.AwaitEndpointSlices(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace, 1, 1)
 	f.AwaitEndpointSlices(framework.ClusterA, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace, 1, 1)
 
-	verifyServiceIpWithDig(f.Framework, framework.ClusterA, framework.ClusterB, nginxServiceClusterB, netshootPodList, checkedDomains,
+	f.VerifyServiceIPWithDig(framework.ClusterA, framework.ClusterB, nginxServiceClusterB, netshootPodList, checkedDomains,
 		"", true)
 
 	f.DeleteServiceExport(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace)
 	f.AwaitServiceImportDelete(framework.ClusterA, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace)
 
-	verifyServiceIpWithDig(f.Framework, framework.ClusterA, framework.ClusterB, nginxServiceClusterB, netshootPodList, checkedDomains,
-		"", false)
+	f.VerifyIPWithDig(framework.ClusterA, nginxServiceClusterB, netshootPodList, checkedDomains, "", "", true)
 }
 
 func RunServicesPodAvailabilityTest(f *lhframework.Framework) {
@@ -231,7 +250,6 @@ func RunServicesPodAvailabilityTest(f *lhframework.Framework) {
 
 	nginxServiceClusterB := f.NewNginxService(framework.ClusterB)
 
-	f.AwaitGlobalnetIP(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace)
 	f.NewServiceExport(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace)
 
 	f.AwaitServiceExportedStatusCondition(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace)
@@ -244,18 +262,24 @@ func RunServicesPodAvailabilityTest(f *lhframework.Framework) {
 	Expect(err).NotTo(HaveOccurred())
 
 	nginxServiceClusterB = svc
-	f.AwaitServiceImportIP(framework.ClusterA, nginxServiceClusterB)
+	f.AwaitServiceImportIP(framework.ClusterB, framework.ClusterA, nginxServiceClusterB)
 	f.AwaitEndpointSlices(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace, 1, 1)
 	f.AwaitEndpointSlices(framework.ClusterA, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace, 1, 1)
 
-	verifyServiceIpWithDig(f.Framework, framework.ClusterA, framework.ClusterB, nginxServiceClusterB, netshootPodList, checkedDomains,
+	f.VerifyServiceIPWithDig(framework.ClusterA, framework.ClusterB, nginxServiceClusterB, netshootPodList, checkedDomains,
 		"", true)
+	verifySRVWithDig(f.Framework, framework.ClusterA, nginxServiceClusterB, netshootPodList, checkedDomains, "",
+		true, true)
 	f.SetNginxReplicaSet(framework.ClusterB, 0)
-	verifyServiceIpWithDig(f.Framework, framework.ClusterA, framework.ClusterB, nginxServiceClusterB, netshootPodList, checkedDomains,
+	f.VerifyServiceIPWithDig(framework.ClusterA, framework.ClusterB, nginxServiceClusterB, netshootPodList, checkedDomains,
 		"", false)
+	verifySRVWithDig(f.Framework, framework.ClusterA, nginxServiceClusterB, netshootPodList, checkedDomains, "",
+		true, false)
 	f.SetNginxReplicaSet(framework.ClusterB, 2)
-	verifyServiceIpWithDig(f.Framework, framework.ClusterA, framework.ClusterB, nginxServiceClusterB, netshootPodList, checkedDomains,
+	f.VerifyServiceIPWithDig(framework.ClusterA, framework.ClusterB, nginxServiceClusterB, netshootPodList, checkedDomains,
 		"", true)
+	verifySRVWithDig(f.Framework, framework.ClusterA, nginxServiceClusterB, netshootPodList, checkedDomains, "",
+		true, true)
 }
 
 func RunServicesPodAvailabilityMutliClusterTest(f *lhframework.Framework) {
@@ -275,7 +299,6 @@ func RunServicesPodAvailabilityMutliClusterTest(f *lhframework.Framework) {
 
 	nginxServiceClusterB := f.NewNginxService(framework.ClusterB)
 
-	f.AwaitGlobalnetIP(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace)
 	f.NewServiceExport(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace)
 
 	f.AwaitServiceExportedStatusCondition(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace)
@@ -287,7 +310,6 @@ func RunServicesPodAvailabilityMutliClusterTest(f *lhframework.Framework) {
 
 	nginxServiceClusterC := f.Framework.NewNginxService(framework.ClusterC)
 
-	f.AwaitGlobalnetIP(framework.ClusterC, nginxServiceClusterC.Name, nginxServiceClusterC.Namespace)
 	f.NewServiceExport(framework.ClusterC, nginxServiceClusterC.Name, nginxServiceClusterC.Namespace)
 
 	By(fmt.Sprintf("Creating a Netshoot Deployment on %q", clusterAName))
@@ -298,34 +320,34 @@ func RunServicesPodAvailabilityMutliClusterTest(f *lhframework.Framework) {
 	Expect(err).NotTo(HaveOccurred())
 
 	nginxServiceClusterC = svc
-	f.AwaitServiceImportIP(framework.ClusterC, nginxServiceClusterC)
+	f.AwaitServiceImportIP(framework.ClusterC, framework.ClusterC, nginxServiceClusterC)
 	f.AwaitEndpointSlices(framework.ClusterC, nginxServiceClusterC.Name, nginxServiceClusterC.Namespace, 2, 2)
 
 	svc, err = f.GetService(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace)
 	Expect(err).NotTo(HaveOccurred())
 
 	nginxServiceClusterB = svc
-	f.AwaitServiceImportIP(framework.ClusterB, nginxServiceClusterB)
+	f.AwaitServiceImportIP(framework.ClusterB, framework.ClusterB, nginxServiceClusterB)
 	f.AwaitEndpointSlices(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace, 2, 2)
 
-	verifyServiceIpWithDig(f.Framework, framework.ClusterA, framework.ClusterB, nginxServiceClusterB, netshootPodList, checkedDomains,
+	f.VerifyServiceIPWithDig(framework.ClusterA, framework.ClusterB, nginxServiceClusterB, netshootPodList, checkedDomains,
 		"", true)
-	verifyServiceIpWithDig(f.Framework, framework.ClusterA, framework.ClusterC, nginxServiceClusterC, netshootPodList, checkedDomains,
+	f.VerifyServiceIPWithDig(framework.ClusterA, framework.ClusterC, nginxServiceClusterC, netshootPodList, checkedDomains,
 		"", true)
 
 	f.SetNginxReplicaSet(framework.ClusterC, 0)
 
 	f.AwaitEndpointSlices(framework.ClusterA, nginxServiceClusterC.Name, nginxServiceClusterC.Namespace, 2, 1)
-	verifyServiceIpWithDig(f.Framework, framework.ClusterA, framework.ClusterA, nginxServiceClusterC, netshootPodList, checkedDomains,
+	f.VerifyServiceIPWithDig(framework.ClusterA, framework.ClusterA, nginxServiceClusterC, netshootPodList, checkedDomains,
 		"", false)
-	verifyServiceIpWithDig(f.Framework, framework.ClusterA, framework.ClusterB, nginxServiceClusterB, netshootPodList, checkedDomains,
+	f.VerifyServiceIPWithDig(framework.ClusterA, framework.ClusterB, nginxServiceClusterB, netshootPodList, checkedDomains,
 		"", true)
 
 	f.SetNginxReplicaSet(framework.ClusterB, 0)
 	f.AwaitEndpointSlices(framework.ClusterA, nginxServiceClusterC.Name, nginxServiceClusterC.Namespace, 2, 0)
-	verifyServiceIpWithDig(f.Framework, framework.ClusterA, framework.ClusterA, nginxServiceClusterC, netshootPodList, checkedDomains,
+	f.VerifyServiceIPWithDig(framework.ClusterA, framework.ClusterA, nginxServiceClusterC, netshootPodList, checkedDomains,
 		"", false)
-	verifyServiceIpWithDig(f.Framework, framework.ClusterA, framework.ClusterB, nginxServiceClusterB, netshootPodList, checkedDomains,
+	f.VerifyServiceIPWithDig(framework.ClusterA, framework.ClusterB, nginxServiceClusterB, netshootPodList, checkedDomains,
 		"", false)
 }
 
@@ -340,7 +362,6 @@ func RunServiceDiscoveryClusterNameTest(f *lhframework.Framework) {
 
 	nginxServiceClusterA := f.Framework.NewNginxService(framework.ClusterA)
 
-	f.AwaitGlobalnetIP(framework.ClusterA, nginxServiceClusterA.Name, nginxServiceClusterA.Namespace)
 	f.NewServiceExport(framework.ClusterA, nginxServiceClusterA.Name, nginxServiceClusterA.Namespace)
 
 	By(fmt.Sprintf("Creating an Nginx Deployment on %q", clusterBName))
@@ -350,7 +371,6 @@ func RunServiceDiscoveryClusterNameTest(f *lhframework.Framework) {
 
 	nginxServiceClusterB := f.NewNginxService(framework.ClusterB)
 
-	f.AwaitGlobalnetIP(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace)
 	f.NewServiceExport(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace)
 
 	f.AwaitServiceExportedStatusCondition(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace)
@@ -363,21 +383,25 @@ func RunServiceDiscoveryClusterNameTest(f *lhframework.Framework) {
 	Expect(err).NotTo(HaveOccurred())
 
 	nginxServiceClusterA = svc
-	f.AwaitServiceImportIP(framework.ClusterA, nginxServiceClusterA)
+	f.AwaitServiceImportIP(framework.ClusterA, framework.ClusterA, nginxServiceClusterA)
 	f.AwaitEndpointSlices(framework.ClusterA, nginxServiceClusterA.Name, nginxServiceClusterA.Namespace, 2, 2)
 
-	verifyServiceIpWithDig(f.Framework, framework.ClusterA, framework.ClusterA, nginxServiceClusterA, netshootPodList, checkedDomains,
+	f.VerifyServiceIPWithDig(framework.ClusterA, framework.ClusterA, nginxServiceClusterA, netshootPodList, checkedDomains,
 		clusterAName, true)
+	verifySRVWithDig(f.Framework, framework.ClusterA, nginxServiceClusterA, netshootPodList, checkedDomains, clusterAName,
+		true, true)
 
 	svc, err = f.GetService(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace)
 	Expect(err).NotTo(HaveOccurred())
 
 	nginxServiceClusterB = svc
-	f.AwaitServiceImportIP(framework.ClusterA, nginxServiceClusterB)
+	f.AwaitServiceImportIP(framework.ClusterB, framework.ClusterA, nginxServiceClusterB)
 	f.AwaitEndpointSlices(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace, 2, 2)
 
-	verifyServiceIpWithDig(f.Framework, framework.ClusterA, framework.ClusterB, nginxServiceClusterB, netshootPodList, checkedDomains,
+	f.VerifyServiceIPWithDig(framework.ClusterA, framework.ClusterB, nginxServiceClusterB, netshootPodList, checkedDomains,
 		clusterBName, true)
+	verifySRVWithDig(f.Framework, framework.ClusterA, nginxServiceClusterB, netshootPodList, checkedDomains, clusterBName,
+		true, true)
 }
 
 func RunServiceDiscoveryRoundRobinTest(f *lhframework.Framework) {
@@ -397,7 +421,6 @@ func RunServiceDiscoveryRoundRobinTest(f *lhframework.Framework) {
 
 	nginxServiceClusterB := f.NewNginxService(framework.ClusterB)
 
-	f.AwaitGlobalnetIP(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace)
 	f.NewServiceExport(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace)
 
 	f.AwaitServiceExportedStatusCondition(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace)
@@ -409,7 +432,6 @@ func RunServiceDiscoveryRoundRobinTest(f *lhframework.Framework) {
 
 	nginxServiceClusterC := f.Framework.NewNginxService(framework.ClusterC)
 
-	f.AwaitGlobalnetIP(framework.ClusterC, nginxServiceClusterC.Name, nginxServiceClusterC.Namespace)
 	f.NewServiceExport(framework.ClusterC, nginxServiceClusterC.Name, nginxServiceClusterC.Namespace)
 
 	By(fmt.Sprintf("Creating a Netshoot Deployment on %q", clusterAName))
@@ -420,29 +442,23 @@ func RunServiceDiscoveryRoundRobinTest(f *lhframework.Framework) {
 	Expect(err).NotTo(HaveOccurred())
 
 	nginxServiceClusterC = svc
-	f.AwaitServiceImportIP(framework.ClusterC, nginxServiceClusterC)
+	f.AwaitServiceImportIP(framework.ClusterC, framework.ClusterC, nginxServiceClusterC)
 	f.AwaitEndpointSlices(framework.ClusterC, nginxServiceClusterC.Name, nginxServiceClusterC.Namespace, 2, 2)
 
 	svc, err = f.GetService(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace)
 	Expect(err).NotTo(HaveOccurred())
 
 	nginxServiceClusterB = svc
-	f.AwaitServiceImportIP(framework.ClusterB, nginxServiceClusterB)
+	f.AwaitServiceImportIP(framework.ClusterB, framework.ClusterB, nginxServiceClusterB)
 	f.AwaitEndpointSlices(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace, 2, 2)
 
 	var serviceIPList []string
 
-	serviceIPClusterB, ok := nginxServiceClusterB.Annotations[submarinerIpamGlobalIp]
-	if !ok {
-		serviceIPClusterB = nginxServiceClusterB.Spec.ClusterIP
-	}
+	serviceIPClusterB := f.GetServiceIP(framework.ClusterB, nginxServiceClusterB, false)
 
 	serviceIPList = append(serviceIPList, serviceIPClusterB)
 
-	serviceIPClusterC, ok := nginxServiceClusterC.Annotations[submarinerIpamGlobalIp]
-	if !ok {
-		serviceIPClusterC = nginxServiceClusterC.Spec.ClusterIP
-	}
+	serviceIPClusterC := f.GetServiceIP(framework.ClusterC, nginxServiceClusterB, false)
 
 	serviceIPList = append(serviceIPList, serviceIPClusterC)
 
@@ -459,7 +475,6 @@ func RunServicesClusterAvailabilityMutliClusterTest(f *lhframework.Framework) {
 
 	nginxServiceClusterB := f.NewNginxService(framework.ClusterB)
 
-	f.AwaitGlobalnetIP(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace)
 	f.NewServiceExport(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace)
 
 	f.AwaitServiceExportedStatusCondition(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace)
@@ -472,7 +487,7 @@ func RunServicesClusterAvailabilityMutliClusterTest(f *lhframework.Framework) {
 	Expect(err).NotTo(HaveOccurred())
 
 	nginxServiceClusterB = svc
-	f.AwaitServiceImportIP(framework.ClusterA, nginxServiceClusterB)
+	f.AwaitServiceImportIP(framework.ClusterB, framework.ClusterA, nginxServiceClusterB)
 	f.AwaitEndpointSlices(framework.ClusterB, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace, 1, 1)
 	f.AwaitEndpointSlices(framework.ClusterA, nginxServiceClusterB.Name, nginxServiceClusterB.Namespace, 1, 1)
 
@@ -482,7 +497,6 @@ func RunServicesClusterAvailabilityMutliClusterTest(f *lhframework.Framework) {
 
 	nginxServiceClusterC := f.NewNginxService(framework.ClusterC)
 
-	f.AwaitGlobalnetIP(framework.ClusterC, nginxServiceClusterC.Name, nginxServiceClusterC.Namespace)
 	f.NewServiceExport(framework.ClusterC, nginxServiceClusterC.Name, nginxServiceClusterC.Namespace)
 
 	f.AwaitServiceExportedStatusCondition(framework.ClusterC, nginxServiceClusterC.Name, nginxServiceClusterC.Namespace)
@@ -491,69 +505,80 @@ func RunServicesClusterAvailabilityMutliClusterTest(f *lhframework.Framework) {
 	Expect(err).NotTo(HaveOccurred())
 
 	nginxServiceClusterC = svc
-	f.AwaitServiceImportIP(framework.ClusterA, nginxServiceClusterC)
+	f.AwaitServiceImportIP(framework.ClusterC, framework.ClusterA, nginxServiceClusterC)
 	f.AwaitEndpointSlices(framework.ClusterA, nginxServiceClusterC.Name, nginxServiceClusterC.Namespace, 2, 2)
 
-	verifyServiceIpWithDig(f.Framework, framework.ClusterA, framework.ClusterB, nginxServiceClusterB, netshootPodList,
+	f.VerifyServiceIPWithDig(framework.ClusterA, framework.ClusterB, nginxServiceClusterB, netshootPodList,
 		checkedDomains, "", true)
-	verifyServiceIpWithDig(f.Framework, framework.ClusterA, framework.ClusterC, nginxServiceClusterC, netshootPodList,
+	f.VerifyServiceIPWithDig(framework.ClusterA, framework.ClusterC, nginxServiceClusterC, netshootPodList,
 		checkedDomains, "", false)
 }
 
-func verifyServiceIpWithDig(f *framework.Framework, srcCluster, targetCluster framework.ClusterIndex, service *corev1.Service,
-	targetPod *corev1.PodList, domains []string, clusterName string, shouldContain bool) {
-	var serviceIP string
-	var ok bool
-
-	serviceIP, ok = service.Annotations[submarinerIpamGlobalIp]
-	if !ok || srcCluster == targetCluster {
-		serviceIP = service.Spec.ClusterIP
-	}
-
-	cmd := []string{"dig", "+short"}
-
-	var clusterDNSName string
-	if clusterName != "" {
-		clusterDNSName = clusterName + "."
-	}
-
+func verifySRVWithDig(f *framework.Framework, srcCluster framework.ClusterIndex, service *corev1.Service, targetPod *corev1.PodList,
+	domains []string, clusterName string, withPort, shouldContain bool) {
+	ports := service.Spec.Ports
 	for i := range domains {
-		cmd = append(cmd, clusterDNSName+service.Name+"."+f.Namespace+".svc."+domains[i])
+		for _, port := range ports {
+			cmd := []string{"dig", "+short", "SRV"}
+
+			clusterDNSName := service.Name + "." + f.Namespace + ".svc." + domains[i]
+
+			if clusterName != "" {
+				clusterDNSName = clusterName + "." + clusterDNSName
+			}
+
+			portName := clusterDNSName
+
+			if withPort {
+				portName = strings.ToLower(port.Name+"."+string(port.Protocol)+".") + portName
+			}
+
+			cmd = append(cmd, portName)
+
+			op := "is"
+			if !shouldContain {
+				op += not
+			}
+
+			By(fmt.Sprintf("Executing %q to verify SRV record for service %q %q discoverable", strings.Join(cmd, " "),
+				service.Name, op))
+			framework.AwaitUntil("verify if service Ports is discoverable", func() (interface{}, error) {
+				stdout, _, err := f.ExecWithOptions(framework.ExecOptions{
+					Command:       cmd,
+					Namespace:     f.Namespace,
+					PodName:       targetPod.Items[0].Name,
+					ContainerName: targetPod.Items[0].Spec.Containers[0].Name,
+					CaptureStdout: true,
+					CaptureStderr: true,
+				}, srcCluster)
+				if err != nil {
+					return nil, err
+				}
+
+				return stdout, nil
+			}, func(result interface{}) (bool, string, error) {
+				var doesContain bool
+				if shouldContain {
+					doesContain = strings.Contains(result.(string), strconv.Itoa(int(port.Port))) &&
+						strings.Contains(result.(string), clusterDNSName)
+				} else {
+					doesContain = strings.Contains(result.(string), strconv.Itoa(int(port.Port))) ||
+						strings.Contains(result.(string), clusterDNSName)
+				}
+
+				By(fmt.Sprintf("Validating that port in dig result for SRV Record %q %s %d and the domain name %s %q", result,
+					op, port.Port, op, clusterDNSName))
+				if doesContain && !shouldContain {
+					return false, fmt.Sprintf("expected execution result %q not to contain %d", result, port.Port), nil
+				}
+
+				if !doesContain && shouldContain {
+					return false, fmt.Sprintf("expected execution result %q to contain %q", result, port.Port), nil
+				}
+				return true, "", nil
+			})
+		}
 	}
-
-	op := "is"
-	if !shouldContain {
-		op += " not"
-	}
-
-	By(fmt.Sprintf("Executing %q to verify IP %q for service %q %q discoverable", strings.Join(cmd, " "), serviceIP, service.Name, op))
-	framework.AwaitUntil("verify if service IP is discoverable", func() (interface{}, error) {
-		stdout, _, err := f.ExecWithOptions(framework.ExecOptions{
-			Command:       cmd,
-			Namespace:     f.Namespace,
-			PodName:       targetPod.Items[0].Name,
-			ContainerName: targetPod.Items[0].Spec.Containers[0].Name,
-			CaptureStdout: true,
-			CaptureStderr: true,
-		}, srcCluster)
-		if err != nil {
-			return nil, err
-		}
-
-		return stdout, nil
-	}, func(result interface{}) (bool, string, error) {
-		doesContain := strings.Contains(result.(string), serviceIP)
-		By(fmt.Sprintf("Validating that dig result %s %q", op, result))
-		if doesContain && !shouldContain {
-			return false, fmt.Sprintf("expected execution result %q not to contain %q", result, serviceIP), nil
-		}
-
-		if !doesContain && shouldContain {
-			return false, fmt.Sprintf("expected execution result %q to contain %q", result, serviceIP), nil
-		}
-
-		return true, "", nil
-	})
 }
 
 func verifyRoundRobinWithDig(f *framework.Framework, srcCluster framework.ClusterIndex, serviceName string, serviceIPList []string,
